unit Unit1;

interface

uses
  Windows, Messages, SysUtils,ActiveX, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, DirectShow, FourCC,MMSystem,ShellAPI,streamclass, StrUtils;

Type
  TMediaStream = Class(TObject)
  public
    Streamtype : String;
    Filesize : int64;
    Duration : string;
    Resolution : string;
    Colordepth : byte;
    Frames : cardinal;
    Framerate : single;
    Codec :  string;
    Ratio : single;
    Bitrate : cardinal;
    Frequency : single;
    Mode : byte;
  published
    constructor Create();
end;

type
  TForm1 = class(TForm)
    Memo1: TMemo;
    ExitButton: TButton;
    OpenButton: TButton;
    CopyButton: TButton;
    OpenDialog1: TOpenDialog;
    AboutButton: TButton;
    procedure FormCreate(Sender: TObject);
    procedure ExitButtonClick(Sender: TObject);
    Procedure FreeMediaType(medType : PAM_MEDIA_TYPE);
    procedure GetFileData(SourceFile : String; Var fAllInfo : String);
    function  GetMediaTypeDescriptionX(MediaType: TAM_Media_Type; MediaLength: Double): string;
    Function  FillZero(S : String; Len : Integer) : String;
    Function  FillZeroMilliSeconds(S:String;Len:Integer):String;
    procedure CopyButtonClick(Sender: TObject);
    procedure OpenButtonClick(Sender: TObject);      //1:12:3 => 01:12:03
    procedure Get;
    function  FileSizeByName(): Cardinal;
    procedure WMDROPFILES(var Message: TWMDROPFILES);message WM_DROPFILES;
    procedure AboutButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;                 
var
  Form1: TForm1;
  SourceFile : String;
  Channels   : string;
  dsMediaLengthStr: String;            //seconds 00,00
  MediaStream : TMediaStream;
implementation

uses Unit2;

{$R *.dfm}

//{$I MediaInfo.pas}

procedure TForm1.FormCreate(Sender: TObject);
begin
  DragAcceptFiles(Form1.Handle, True);  {Let Windows know we accept dropped files}
  if ParamCount > 0 then begin       // if launched with a parameter. ParamStr(0)=Minf.exe, ParamStr(1)=movie filename
    SourceFile := Paramstr(1);
    Get();
  end;
  Application.HintHidePause := 7000;   //7 seconds
end;

procedure TForm1.ExitButtonClick(Sender: TObject);
begin
  Close();
end;

function TForm1.FillZero(S:String;Len:Integer):String;//Fills empty spaces with zeros(4 -> 04)
begin
  While Length(S) < Len do S := '0'+S;
  Result := S;
end;

function TForm1.FillZeroMilliSeconds(S:String;Len:Integer):String;//Used for the millisecond part of Duration). Zero's need to be filled in from other end. If millisecondpart is 2, result=002(=wrong), should be 200.
begin
  While Length(S) < Len do S := S+'0';
  Result := S;
end;
procedure TForm1.CopyButtonClick(Sender: TObject);
var  SelectionStart,
     SelectionLen    : word;
begin
  SelectionStart := Memo1.SelStart;
  SelectionLen := Memo1.SelLength;
  if SelectionLen < 1 then begin
    Memo1.SelectAll;
    Memo1.SetFocus;
    Memo1.CopyToClipboard;
    Memo1.SelLength := 0;
  end
  else begin
  Memo1.SetFocus;
  Memo1.CopyToClipboard;
  Memo1.SelStart := SelectionStart;
  Memo1.SelLength := SelectionLen;
  end;
end;

procedure TForm1.OpenButtonClick(Sender: TObject);
var    SelStart   : Word;
begin
  if SourceFile <> '' then begin                           //open same folder as previous movie
    if DirectoryExists(ExtractFilePath(SourceFile)) then
      OpenDialog1.InitialDir := ExtractFilePath(SourceFile);
  end;
  if openDialog1.Execute = true then begin
    SourceFile := opendialog1.FileName;
    Get();
  end;
end;

procedure TForm1.Get;
var AllInfo       : string ;
    ScrollMessage : TWMVScroll;
begin
  if ExtractFileExt(SourceFile) = '.ogm' then
      MessageDlg('Support for .ogm files is limited. The audio stream is not properly detected. Sorry.',mtInformation,[mbOK],0);

  GetFileData(SourceFile,AllInfo);

  ScrollMessage.Msg:=WM_VScroll;       //Scroll up so the first line is visible. does not work
  ScrollMessage.ScrollCode:=SB_PAGEUP;
  ScrollMessage.Pos:=0;
  Memo1.Dispatch(ScrollMessage);

end;

function TForm1.FileSizeByName(): Cardinal;                          //Gets filesize from file
var     F : File;
begin
  FileMode := fmOpenRead;
  AssignFile(F,SourceFile);
  {$I-}
  Reset(F,1);
  {$I+}
  If IOResult = 0 then
  Begin
    Result := FileSize(F);
    CloseFile(F);
  End
  Else Result := 0;
end;

procedure TForm1.WMDROPFILES(var Message: TWMDROPFILES);
var   buffer     : array[0..255] of char;  //dropped file's filename
begin
  DragQueryFile(Message.Drop, 0, @buffer, sizeof(buffer));  //0 : first item dropped
  SourceFile := buffer;
  Get();
end;

procedure TForm1.FreeMediaType(medType : PAM_MEDIA_TYPE);
begin
  If medType.cbFormat <>   0 then CoTaskMemFree(medType.pbFormat);
  If medType.pUnk     <> nil then medType.pUnk := nil;
  FillChar(medType^,Sizeof(TAM_MEDIA_TYPE),0);
end;

procedure TForm1.GetFileData(SourceFile : String; Var fAllInfo : String);
Var
  dsMediaLength   : Double;            //seconds 00,00
  dsMediaLengthFrac:String;            //millisecond part of seconds (,00)
  dsMediaLenInt   : Integer;           //seconds  00
  dsMediaDet      : IMediaDet;
  dsMediaStreams  : Integer;
  dsMediaType     : TAM_MEDIA_TYPE;
  dsMediaFRate    : Double;
  fDuration       : String;
  I               : Integer;
  hr              : HRESULT;
  dsSec,
  dsMin,
  dsHour          : Integer;
  //=========================================================
  function GetStreamDuration(StreamNumber:byte):string;
  var I : Integer;
  begin
    dsMediaDet.put_CurrentStream(StreamNumber);
    if dsMediaDet.get_StreamLength(dsMediaLength) = S_OK then
    Begin
      dsMediaLenInt := Trunc(dsMediaLength);
      dsHour    := dsMediaLenInt div 3600;
      dsMin     := (dsMediaLenInt-dsHour*3600) div 60;
      dsSec     := (dsMediaLenInt-dsHour*3600-dsMin*60);

      dsMediaLengthStr := FloatToStr(dsMediaLength);
      for I:=0 to Length(dsMediaLengthStr)-1  do
      begin
        if (dsMediaLengthStr[I] = ',') or (dsMediaLengthStr[I] = '.') then                //find the decimal separator
        begin
          dsMediaLengthFrac := Copy(dsMediaLengthStr,I+1,Length(dsMediaLengthStr)-I);     
          if Length(dsMediaLengthFrac) > 3 then
            dsMediaLengthFrac := Copy(dsMediaLengthFrac,0,2);   //returns first 3 characters. Required because sometimes Duration looks like this: 01:00:15:4070738
          Break;
        end;
      end;
      fDuration := FillZero(IntToStr(dsHour),2)+':'+FillZero(IntToStr(dsMin),2)+
        ':'+FillZero(IntToStr(dsSec),2)+':'+FillZeroMilliSeconds(dsMediaLengthFrac,2);
    end
    else begin
      dsMediaLength := 0;
      fDuration := 'Unknown';
    end;
    Result := fDuration
  end;
    //=========================================================
begin
  fAllInfo  := '';
  hr := CoCreateInstance(CLSID_MediaDet, nil, CLSCTX_INPROC, IID_IMediaDet, dsMediaDet);
  if hr <> S_OK then begin
    Showmessage('Media Detector not available');
    exit;
  end;
  hr := dsMediaDet.put_Filename(SourceFile);
  if hr <> S_OK then begin
    dsMediaDet := nil;
    exit;
  end;
  dsMediaDet.get_OutputStreams(dsMediaStreams);

  if dsMediaStreams > 0 then Begin             //if any streams found

    fDuration := GetStreamDuration(0);
    {dsMediaDet.put_CurrentStream(0);
    if dsMediaDet.get_StreamLength(dsMediaLength) = S_OK then
    Begin
      dsMediaLenInt := Trunc(dsMediaLength);
      dsHour    := dsMediaLenInt div 3600;
      dsMin     := (dsMediaLenInt-dsHour*3600) div 60;
      dsSec     := (dsMediaLenInt-dsHour*3600-dsMin*60);

      dsMediaLengthStr := FloatToStr(dsMediaLength);
      for I:=0 to Length(dsMediaLengthStr)-1  do
      begin
        if (dsMediaLengthStr[I] = ',') or (dsMediaLengthStr[I] = '.') then
        begin
          dsMediaLengthFrac := Copy(dsMediaLengthStr,I+1,Length(dsMediaLengthStr)-I);
          if Length(dsMediaLengthFrac) > 3 then
            dsMediaLengthFrac := Copy(dsMediaLengthFrac,0,2);   //returns first 3 characters. Required because sometimes Duration looks like this: 01:00:15:4070738
          Break;
        end;
      end;
      fDuration := FillZero(IntToStr(dsHour),2)+':'+FillZero(IntToStr(dsMin),2)+
        ':'+FillZero(IntToStr(dsSec),2)+':'+FillZeroMilliSeconds(dsMediaLengthFrac,2);
    end
    else begin
      dsMediaLength := 0;
      fDuration := 'Unknown';
    end;
    }

   (* try           //change this to TFileStream. that might work better with some files that give I/O Error
      AssignFile(InputFile,SourceFile);
      {$I+}
      Reset(InputFile);
      {$I-}
    except
      on EInOutError do ;     //some error handling here, perhaps
    end;
    fAllInfo := 'File size:'+#9+IntToStr(FileSize(InputFile)div 1048576)+' MB'
                +#13#10+'Duration: '+#09+fDuration+#13#10;                 //1024*1024=1048576
    CloseFile(InputFile);
   *)
    Application.Title := 'Minf  ['+Sourcefile+']';;
    Form1.Caption := 'Minf  ['+Sourcefile+']';
    Memo1.Clear;
    Memo1.Lines.Add('File:'+#9#9+ExtractFilename(SourceFile));
    Memo1.Lines.Add('Size:'+#9#9+IntToStr(FileSizeByName() div 1048576)+' MB');   //#13 = RETURN
    Memo1.Lines.Add('Duration:'+#9#09+fDuration);
  //  Memo1.Lines.Add('');

//========

    for I := 0 to dsMediaStreams -1 do begin
      MediaStream := TMediaStream.Create();
      dsMediaDet.put_CurrentStream(I);
      dsMediaDet.get_StreamMediaType(dsMediaType);
      dsMediaDet.get_FrameRate(dsMediaFRate);
      MediaStream.Framerate := dsMediaFRate;
      MediaStream.Duration := GetStreamDuration(I);
      GetMediaTypeDescriptionX(dsMediaType, dsMediaLength);
      Memo1.Lines.Add('');
      if MediaStream.Streamtype = 'Video' then
      begin
        Memo1.Lines.Add('Stream '+IntToStr(I+1)+'  --  '+MediaStream.Streamtype);
        Memo1.Lines.Add('===========================');
        Memo1.Lines.Add('  Resolution: '+#9+MediaStream.Resolution);
        Memo1.Lines.Add('  Codec: '+#9#9+MediaStream.Codec);
        Memo1.Lines.Add('  Frames: '+#9#9+IntToStr(MediaStream.Frames));
        Memo1.Lines.Add('  Frames/sec: '+#9+FloatToStrF(MediaStream.Framerate,ffFixed,15,3));
        Memo1.Lines.Add('  Duration: '#9+MediaStream.Duration);
        Memo1.Lines.Add('  Color depth: '+#9+IntToStr(MediaStream.Colordepth)+' bit');
        Memo1.Lines.Add('  Ratio: '+#9#9+FloatToStrF(MediaStream.Ratio,ffFixed,15,2));
      end;
      if MediaStream.Streamtype = 'Audio' then
      begin
        Memo1.Lines.Add('Stream '+IntToStr(I+1)+'  --  '+MediaStream.Streamtype);
        Memo1.Lines.Add('===========================');
        Memo1.Lines.Add('  Codec: '+#9#9+MediaStream.Codec);
        Memo1.Lines.Add('  Sample rate: '+#9+FloatToStrF(MediaStream.Frequency,ffFixed,15,1)+' kHz');
        Memo1.Lines.Add('  Average bitrate: '+#9+FloatToStrF(MediaStream.Bitrate,ffFixed,15,0)+' kbit/sec');
        Memo1.Lines.Add('  Duration: '#9+MediaStream.Duration);
        if MediaStream.Mode = 1 then Memo1.Lines.Add('  Channels: '+#9+IntToStr(MediaStream.Mode)+' (mono)') else
        if MediaStream.Mode = 2 then Memo1.Lines.Add('  Channels: '+#9+IntToStr(MediaStream.Mode)+' (stereo)') else
        Memo1.Lines.Add('  Channels: '+#9+IntToStr(MediaStream.Mode));
      end;

      if MediaStream.Streamtype = 'Ogg audio' then
      begin
        Memo1.Lines.Add('Stream '+IntToStr(I+1)+'  --  '+MediaStream.Streamtype);
        Memo1.Lines.Add('===========================');
        Memo1.Lines.Add('  Codec: '+#9#9+MediaStream.Codec);
        Memo1.Lines.Add('  Sample rate: '+#9+FloatToStrF(MediaStream.Frequency,ffFixed,15,1)+' kHz');
        Memo1.Lines.Add('  Average bitrate: '+#9+FloatToStrF(MediaStream.Bitrate,ffFixed,15,0)+' kbit/sec');
        Memo1.Lines.Add('  Duration: '#9+MediaStream.Duration);
        if MediaStream.Mode = 1 then Memo1.Lines.Add('  Channels: '+#9+IntToStr(MediaStream.Mode)+' (mono)') else
        if MediaStream.Mode = 2 then Memo1.Lines.Add('  Channels: '+#9+IntToStr(MediaStream.Mode)+' (stereo)') else
        Memo1.Lines.Add('  Channels: '+#9+IntToStr(MediaStream.Mode));
      end;

      if MediaStream.Streamtype = 'Unknown' then
      begin
        Memo1.Lines.Add('Stream '+IntToStr(I+1)+'  --  '+MediaStream.Streamtype);
      end;

      FreeMediaType(@dsMediaType);
      MediaStream.Free;
      //Memo1.Lines.Add('');

    end;

//========
  end;
  dsMediaDet := nil;
 // Memo1.Lines.Delete(Memo1.Lines.Count-1);      //because last line is empty

end;

function TForm1.GetMediaTypeDescriptionX(MediaType: TAM_Media_Type; MediaLength: Double): string;

   function ConvertFloat(Num: Double): string;
   begin
     if Frac(Num) = 0 then result := FloatToStrF(Num,ffFixed,15,0)
     else result := FloatToStrF(Num,ffFixed,15,3);
   end;

begin   // major types
  result := '';
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_Video)         then MediaStream.Streamtype := 'Video'         else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_Audio)         then MediaStream.Streamtype := 'Audio'         else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_AnalogAudio)   then MediaStream.Streamtype := 'AnalogAudio'   else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_AnalogVideo)   then MediaStream.Streamtype := 'Analogvideo'   else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_AUXLine21Data) then MediaStream.Streamtype := 'AUXLine21Data' else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_File)          then MediaStream.Streamtype := 'File'          else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_Interleaved)   then MediaStream.Streamtype := 'Interleaved'   else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_LMRT)          then MediaStream.Streamtype := 'LMRT'          else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_Midi)          then MediaStream.Streamtype := 'Midi'          else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_MPEG2_PES)     then MediaStream.Streamtype := 'MPEG2_PES'     else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_ScriptCommand) then MediaStream.Streamtype := 'ScriptCommand' else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_Stream)        then MediaStream.Streamtype := 'Stream'        else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_Text)          then MediaStream.Streamtype := 'Text'          else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_Timecode)      then MediaStream.Streamtype := 'Timecode'      else
  if IsEqualGUID(MediaType.majortype,MEDIATYPE_URL_STREAM)    then MediaStream.Streamtype := 'URL_STREAM'    else
     MediaStream.Streamtype := 'Unknown';

  if IsEqualGUID(MediaType.formattype,FORMAT_VideoInfo) then
  begin
    if ((MediaType.cbFormat > 0) and assigned(MediaType.pbFormat)) then
    begin
      if PVideoInfoHeader(MediaType.pbFormat)^.AvgTimePerFrame > 0 then
        MediaStream.Framerate := 10000000 / PVideoInfoHeader(MediaType.pbFormat)^.AvgTimePerFrame
      else
        MediaStream.Framerate := 0;
      with PVideoInfoHeader(MediaType.pbFormat)^.bmiHeader do
      begin
        MediaStream.Resolution := IntToStr(biWidth)+'x'+IntToStr(biHeight);
        MediaStream.Colordepth := biBitCount;
        MediaStream.Frames     := trunc(MediaStream.Framerate*MediaLength);
        MediaStream.Framerate  := MediaStream.Framerate;
        MediaStream.Codec      := GetVideoFourCC(biCompression);
        MediaStream.Ratio      := biWidth/biHeight;
      end;
    end;
  end   //IsEqualGUID(MediaType.formattype,FORMAT_VideoInfo)
  else begin
    if IsEqualGUID(MediaType.formattype,FORMAT_VideoInfo2) then
    begin
      if ((MediaType.cbFormat > 0) and assigned(MediaType.pbFormat)) then
      begin
        if PVideoInfoHeader2(MediaType.pbFormat)^.AvgTimePerFrame > 0 then
          MediaStream.Framerate := 10000000 / PVideoInfoHeader2(MediaType.pbFormat)^.AvgTimePerFrame
        else
          MediaStream.Framerate := 0;
        with PVideoInfoHeader2(MediaType.pbFormat)^.bmiHeader do
        begin
          MediaStream.Resolution := IntToStr(biWidth)+'x'+IntToStr(biHeight);
          MediaStream.Colordepth := biBitCount;
          MediaStream.Frames     := trunc(MediaStream.Framerate*MediaLength);
          MediaStream.Framerate  := MediaStream.Framerate;
          MediaStream.Codec      := GetVideoFourCC(biCompression);
          MediaStream.Ratio      := biWidth/biHeight;
        end;
      end;
    end
    else begin  //IsEqualGUID(MediaType.formattype,FORMAT_VideoInfo2)
      if IsEqualGUID(MediaType.formattype,FORMAT_WaveFormatEx) then
      begin
        if ((MediaType.cbFormat > 0) and assigned(MediaType.pbFormat)) then
        begin
          with PWaveFormatEx(MediaType.pbFormat)^ do
          begin
            MediaStream.Codec     := GetAudioTwoCC(wFormatTag);
            MediaStream.Bitrate   := trunc(nAvgBytesPerSec*8/1000);
            MediaStream.Frequency := nSamplesPerSec/1000;
            MediaStream.Mode      := nChannels;
          end;
        end;
      end
      else
      begin
        if IsEqualGUID(MediaType.formattype,FORMAT_MPEGVideo) then
        begin
          if ((MediaType.cbFormat > 0) and assigned(MediaType.pbFormat)) then begin
            if PMPEG1VIDEOINFO(MediaType.pbFormat)^.hdr.AvgTimePerFrame > 0 then
              MediaStream.Framerate := 10000000 / PMPEG1VIDEOINFO(MediaType.pbFormat)^.hdr.AvgTimePerFrame
            else
              MediaStream.Framerate := 0;

          with PMPEG1VIDEOINFO(MediaType.pbFormat)^.hdr.bmiHeader do
          begin
            MediaStream.Resolution := IntToStr(biWidth)+'x'+IntToStr(biHeight);
            MediaStream.Colordepth := biBitCount;
            MediaStream.Frames     := trunc(MediaStream.Framerate*MediaLength);
            MediaStream.Framerate  := MediaStream.Framerate;
            MediaStream.Codec      := GetVideoFourCC(biCompression);
            MediaStream.Ratio      := biWidth/biHeight;
           end;
          end;
        end
        else
        begin
          if IsEqualGUID(MediaType.formattype,FORMAT_MPEG2Video) then
          begin
            if ((MediaType.cbFormat > 0) and assigned(MediaType.pbFormat)) then begin
              if PMPEG2VIDEOINFO(MediaType.pbFormat)^.hdr.AvgTimePerFrame > 0 then
                MediaStream.Framerate := 10000000 / PMPEG2VIDEOINFO(MediaType.pbFormat)^.hdr.AvgTimePerFrame
              else
                MediaStream.Framerate := 0;
              with PMPEG2VIDEOINFO(MediaType.pbFormat)^.hdr.bmiHeader do
              begin
                MediaStream.Resolution := IntToStr(biWidth)+'x'+IntToStr(biHeight);
                MediaStream.Bitrate    := biBitCount;
                MediaStream.Frames     := trunc(MediaStream.Framerate*MediaLength);
                MediaStream.Framerate  := MediaStream.Framerate;
                MediaStream.Codec      := GetVideoFourCC(biCompression);
                MediaStream.Ratio      := biWidth/biHeight;
              end;
            end;
          end
          else begin
            if IsEqualGUID(MediaType.formattype,FORMAT_OggAudio) then
            begin
              MediaStream.Streamtype := 'Ogg audio' ;
              if ((MediaType.cbFormat > 0) and assigned(MediaType.pbFormat)) then
              begin
                with PWaveFormatEx(MediaType.pbFormat)^ do
                begin   //codec,bitrate and mode is wrong.
                  MediaStream.Codec     := GetAudioTwoCC(wFormatTag);    //?
                  MediaStream.Bitrate   := trunc(nAvgBytesPerSec*8/1000); // ?
                  MediaStream.Frequency := nSamplesPerSec/1000;
                  MediaStream.Mode      := nChannels;                     //?
                end;
              end;
            end
          //end
          else begin  // todo
            if IsEqualGUID(MediaType.formattype,FORMAT_DvInfo)        then MediaStream.Streamtype := 'DvInfo' else
            if IsEqualGUID(MediaType.formattype,FORMAT_MPEGStreams)   then MediaStream.Streamtype := 'MPEGStreams' else
            if IsEqualGUID(MediaType.formattype,FORMAT_DolbyAC3)      then MediaStream.Streamtype := 'DolbyAC3' else
            if IsEqualGUID(MediaType.formattype,FORMAT_MPEG2Audio)    then MediaStream.Streamtype := 'MPEG2Audio' else
            if IsEqualGUID(MediaType.formattype,FORMAT_DVD_LPCMAudio) then MediaStream.Streamtype := 'DVD_LPCMAudio'
              else  MediaStream.Streamtype := 'Unknown';
          end;
        end;
      end;
    end;
  end;
  end;
end;

constructor TMediaStream.Create();
begin
  ;
end;

procedure TForm1.AboutButtonClick(Sender: TObject);
begin
  AboutForm.ShowModal;
end;

{procedure TForm1.FormShow(Sender: TObject);
var I : byte;
begin
  AlphaBlend := True;
  For I:=0 to 80 do
  begin
    AlphaBlendValue := I*3;
    sleep(2);
  end;
  AlphaBlend := false;
end;
  }
end.

{  How display results?
   ====================
-----------------------------------------------   

File size:	        696 MB
Duration:	          00:48:36:020

Stream 1  --  Video
===========================
  Resolution: 	    640x272
  Codec: 		        XviD MPEG-4 codec
  Frames: 		      94236
  Frames/sec: 	    25,000
  Duration: 	      01:02:49:44
  Color depth: 	    12 bit

Stream 2  --  Audio
===========================
  Codec: 		        FAST Multimedia AG DVM (Dolby AC3)
  Sample rate: 	    48,0 kHz
  Average Bitrate: 	384 kbit/sec
  Duration: 	      01:02:49:417

Stream 3  --  Audio
===========================
  Codec: 		        FAST Multimedia AG DVM (Dolby AC3)
  Sample rate: 	    48,0 kHz
  Average Bitrate: 	96 kbit/sec
  Duration: 	      01:02:49:416

---------------------------------------------------------------

}
